pub enum RouteError<E> {
AppSpecific(E),
Request(RequestError),
UnsupportedContentType,
Binary(Error),
Json(Error),
Tide {
status: StatusCode,
message: String,
},
ExportMetrics(String),
IncorrectMethod {
expected: String,
},
}Expand description
An error returned by a route handler.
RouteError encapsulates application specific errors E returned by the user-installed handler
itself. It also includes errors in the route dispatching logic, such as failures to turn the
result of the user-installed handler into an HTTP response.
Variants
AppSpecific(E)
Request(RequestError)
UnsupportedContentType
Binary(Error)
Json(Error)
Tide
ExportMetrics(String)
IncorrectMethod
Implementations
Sourceimpl<E> RouteError<E>
impl<E> RouteError<E>
pub fn status(&self) -> StatusCode
pub fn map_app_specific<E2>(self, f: impl Fn(E) -> E2) -> RouteError<E2>